//  **********************************************************************
//  * Copyright (C) 2012, The YaDICs Project Developers. 
//  * See the COPYRIGHT file at the top-level directory of this distribution ./COPYRIGHT.
//  * See ./COPYING file for copying and redistribution conditions.
//  * 
//  * This file is part of YaDICs.
//  * YaDICs is free software: you can redistribute it and/or modify
//  * it under the terms of the GNU General Public License as published by
//  * the Free Software Foundation, either version 3 of the License, or
//  * (at your option) any later version.
//  * 
//  * YaDICs is distributed in the hope that it will be useful,
//  * but WITHOUT ANY WARRANTY; without even the implied warranty of
//  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  * GNU General Public License for more details.
//  * 
//  * You should have received a copy of the GNU General Public License
//  * along with YaDICs.  If not, see <http://www.gnu.org/licenses/>.
//  * 
//  * Information about how to use the software are provided at http://yadic.univ-lille1.fr/
//  **********************************************************************

netcdf DIC_parameter_file {

dimensions:


	dim_sample = UNLIMITED;

	dim_tmp = 21;// number of sample to correlate
	
// 	don't change
	dim_system = 1;// number of image composing the observed field
	dim_camera = 1;// number of camera
	dim_image = 2;// number of image to correlate
	dim_string = 180;// image name length
	
// 	change only if mod_image
	dim_mode = 1;//number of image modes plus 1
	dim_space = 2;//associated dimensions
	
	
variables:

//input_outpout format definition
  byte format;
    format:type = "float_float";

    
    
//---------------------------Mesh------------------------------
// example of InterCorrelation mesh definition
 byte mesh_IC;
	mesh_IC:path = "none";// for external mesh (not activated yet)
	mesh_IC:type = "generate_centroid";// default for block-matching (don't change)
	mesh_IC:pitch = 16,16;// pitch between two windows
	mesh_IC:window = 16,16;// windows size
	mesh_IC:component = "x,y";// space component (x,y and z-if 3D)
	mesh_IC:store_peak = 1;// number of intercorrelation peak to store
	
// example of Optical Flow Integrated per Block mesh definition
 byte mesh_OFIB;
	mesh_OFIB:path = "none";// for external mesh (not activated yet)
	mesh_OFIB:type = "generate_centroid_integrated";// default for OFIB (don't change)
	mesh_OFIB:pitch = 16,16;// pitch between two windows
	mesh_OFIB:window = 16,16;// windows size
	mesh_OFIB:component = "x,y";// space component (x,y and z-if 3D)

// example of Optical Flow Integrated mesh definition
  byte mesh_OFI;
	mesh_OFI:path = "none";// for external mesh (not activated yet)
	mesh_OFI:type = "global";// default for OFI (don't change)
	mesh_OFI:component = "x,y";// space component (x,y and z-if 3D)
	
// example of Optical Flow Finite Element Method mesh definition
  byte mesh_OFFEM;
	mesh_OFFEM:path = "none";// for external mesh (not activated yet)
	mesh_OFFEM:type = "generate_regularFem";// default for OFFEM (don't change)
	mesh_OFFEM:pitch = 16,16;// pitch between two windows
	mesh_OFFEM:component = "x,y";// space component (x,y and z-if 3D)
//---------------------------Mesh------------------------------	
	
	
	
//---------------------------Correlation Method----------------
//example of "Inter-Correlation" method definition
  byte IC;
	IC:type = "IC_fftw";
	IC:phase_threshold = 1;//only for IC_fftw_phase
	IC:mesh = "mesh_IC";// associated mesh
	IC:peak = "interpP";// sub-pix interpolation method [interG ...]
	IC:median_filter = 3;// box for median filter [+-(mf-1)/2] in element box (window)
	IC:store_correlogram = 0; // 0 = no store ; other correlogram are stored in netcdf
	
//example of "Optical Flow Integrated" method definition for "Homogenous strain"
  byte OFI_H;
	OFI_H:type = "OFI";// Optical-Flow Integrated
	OFI_H:mesh = "mesh_OFI";// associated mesh
	OFI_H:shape = "homogeneous";// assumed kinematics [rigid_body, homogeneous, blade,brasilian,image]
	OFI_H:modes = "Tx,Ty,Rz,Exx,Eyy,Exy";// desired modes
	OFI_H:refX = -1;//shape function X reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFI_H:refY = -1;//shape function Y reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFI_H:refZ = -1;//shape function Z reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFI_H:convergence_speed = 1e-3;//convergence criterion (Epsilon_(i+1) - Epsilon(i)<convergence_speed)
	OFI_H:interpolation_loop = "cubic";//cubic or linear by default - during iterations
	OFI_H:interpolation_final = "cubic";//cubic or linear by default - at the final iteration
	
//example of "Optical Flow Integrated" method definition for "rigid body motion"
  byte OFI_RB;
	OFI_RB:type = "OFI";// Optical-Flow Integrated
	OFI_RB:mesh = "mesh_OFI";// associated mesh
	OFI_RB:shape = "rigid_body";// assumed kinematics [rigid_body, homogeneous, blade,brasilian,image]
	OFI_RB:modes = "Tx,Ty,Rz";// desired modes
	OFI_RB:refX = -1;//shape function X reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFI_RB:refY = -1;//shape function Y reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFI_RB:refZ = -1;//shape function Z reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFI_RB:convergence_speed = 1e-3;//convergence criterion (Epsilon_(i+1) - Epsilon(i)<convergence_speed)
	OFI_RB:interpolation_loop = "cubic";//cubic or linear by default - during iterations
	OFI_RB:interpolation_final = "cubic";//cubic or linear by default - at the final iteration
	
//example of "Optical Flow Integrated per block" method definition
  byte OFIB;
	OFIB:type = "OFIB";// Optical-Flow Integrated per Block
	OFIB:mesh = "mesh_OFIB";// associated mesh
	OFIB:shape = "rigid_body";// assumed kinematics [rigid_body, homogeneous, blade,brasilian,image]
	OFIB:modes = "Tx,Ty,Rz";// desired modes
	OFIB:refX = -1;//shape function X reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFIB:refY = -1;//shape function Y reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFIB:refZ = -1;//shape function Z reference, -1 = automatic: system reference a the center of image/ either location in pix
	OFIB:convergence_speed = 1e-3;//convergence criterion (Epsilon_(i+1) - Epsilon(i)<convergence_speed)
	OFIB:median_filter = 3;// box for median filter [+-(mf-1)/2] in element box (window)
	OFIB:interpolation_loop = "cubic";//cubic or linear by default - during iterations
	OFIB:interpolation_final = "cubic";//cubic or linear by default - at the final iteration
	
//example of "Optical Flow Finite Element Method" method definition
  byte OFFEM;
	OFFEM:type = "OFFEM";// Optical-Flow Integrated
	OFFEM:mesh = "mesh_OFFEM";// associated mesh
	OFFEM:method = "gradient";// optimization method - newton or gradient
	OFFEM:alpha0 = 5e-1;// init coef for gradient method
	OFFEM:shape = "Q4";// assumed kinematics C8 for 3D
	OFFEM:convergence_speed = 1e-3;//convergence criterion (Epsilon_(i+1) - Epsilon(i)<convergence_speed)
	OFFEM:median_filter = 3;// box for median filter [+-(mf-1)/2] in element box (window)
	OFFEM:iter_max = 100;//max number of authorized iterations
	OFFEM:interpolation_loop = "cubic";//cubic or linear by default - during iterations
	OFFEM:interpolation_final = "cubic";//cubic or linear by default - at the final iteration
//-------------------------ls--Correlation Method----------------

	

//------------Correlation sequence per image couple------------
  byte sequence; 
	sequence:analysis = "OFI_H,OFI_H,OFFEM,OFFEM,OFFEM,OFFEM,OFFEM";//correlation sequence list
	sequence:filter = 6,5,4,3,2,1,0;//associated pyramidal filter: super-pixel = 2^i x 2^i pix, e.g. i=0->1x1, i=6->64x64 
//------------Correlation sequence per image couple------------


//------------------------image list---------------------------
  char image_list(dim_sample, dim_tmp, dim_image, dim_string);
  
	  image_list:type = "File";//image capture from File or on-fly Grab(not activated yet)
	  image_list:mask = "mask.png";// mask name (must be in "path" directory)
	  image_list:mode = 0;// 0:dependent mode (Image sequence) - 1:separate mode (PIV)
	  image_list:path = "./img/";// image location
	  
	  
  //declare desired outputs and physical pixel size
  float output;
	  output:display_mode = 0;//Allow a real time field display (not activated yet)
	  output:store_img = 0;//store input data in netcdf format
	  output:store_def = 1;//store the deformed image after correction
	  output:store_field = 1;//store converged displacement fields
	  output:store_res = 1;//store converged residue fields
	  output:store_strain = 0;//store converged residue field (not activated yet)
	  output:ratio_pxmm = 65;//Allow to output fields in physical units (bug only put integers, i.e. not 6.5 um but 650 nm for example)
	  output:format = "";//tiff or netcdf default
//------------------------image list---------------------------

  char mode_img(dim_sample, dim_mode, dim_space, dim_string);  
  
//------------------------image list--------------------------- 
// allocate variables
data:

  format = 1;

  mesh_IC = 1;
  mesh_OFIB = 1;
  mesh_OFI = 1;
  mesh_OFFEM = 1;
  
  IC = 1;
  OFI_H = 1;
  OFI_RB = 1;
  OFIB = 1;
  OFFEM = 1;
  
  sequence =1;
  
//   image list: image ref, image def0, ......., image ref, image defn;
  image_list = 
"image30001.tif", "image30029.tif", 
// "image30001.tif", "image30030.tif", 
"image30001.tif", "image30031.tif", 
// "image30001.tif", "image30032.tif", 
// "image30001.tif", "image30033.tif",
"image30001.tif", "image30034.tif", 
// "image30001.tif", "image30035.tif", 
"image30001.tif", "image30036.tif", 
// "image30001.tif", "image30037.tif",
"image30001.tif", "image30038.tif", 
// "image30001.tif", "image30039.tif", 
"image30001.tif", "image30040.tif", 
/*"image30001.tif", "image30041.tif",*/ 
"image30001.tif", "image30042.tif", 
"image30001.tif", "image30043.tif";
// "image30001.tif", "image30044.tif", 
// "image30001.tif", "image30045.tif", 
// "image30001.tif", "image30046.tif", 
// "image30001.tif", "image30047.tif", 
// "image30001.tif", "image30048.tif", 
// "image30001.tif", "image30049.tif";

//only for mod_image
  mode_img =  
"T.png",	"zero.png",
"zero.png",	"T.png",
"Exx.png",	"zero.png",
"zero.png",	"Eyy.png",
"Eyy.png",	"Exx.png";
  

}


